@@ -1,6 +1,3 @@
-from tracemalloc import start
-
-
 def start_server(**message):
   from flask import Flask
   from flask import Flask, render_template, redirect
@@ -12,16 +9,7 @@ def start_server(**message):
     return message
   app.run(host='0.0.0.0', port=6969)
 
-
-def run():
-  from flask import Flask
-  from flask import Flask, render_template, redirect
-  app = Flask('app')
-  app.run(host='0.0.0.0', port=6969)
-
 def thread():
     from threading import Thread
-    start_server()
-    t = Thread(target=run)
-    t.start()
-    return True
+    thread_data = Thread(target=start_server)
+    return thread_data
\ No newline at end of file
